@@ -17,9 +17,9 @@ Chj::IO::PipelessCommand
     use Chj::xopen qw(xopen_read);
     use Chj::xtmpfile;
 
-    my $in= xopen_read $inpath;
-    my $out= xtmpfile $outpath;
-    my $c= Chj::IO::PipelessCommand
+    my $in = xopen_read $inpath;
+    my $out = xtmpfile $outpath;
+    my $c = Chj::IO::PipelessCommand
                ->new_with_in_out ($in,$out, $path, @args);
     # $c can't be read from or written to.
     $c->xxfinish;
@@ -34,25 +34,26 @@ or on the L<website|http://functional-perl.org/>.
 
 =cut
 
-
 package Chj::IO::PipelessCommand;
 
-use strict; use warnings; use warnings FATAL => 'uninitialized';
+use strict;
+use warnings;
+use warnings FATAL => 'uninitialized';
 
 use base qw(
-            Chj::IO::CommandCommon
-           );
+    Chj::IO::CommandCommon
+);
 
 sub new_with_in_out {
-    my $class=shift;
-    my $infh=shift;
-    my $outfh=shift;
-    my $self= bless {}, $class;
-    $self->xlaunch3($infh,$outfh,undef,@_);
+    my $class = shift;
+    my $infh  = shift;
+    my $outfh = shift;
+    my $self  = bless {}, $class;
+    $self->xlaunch3($infh, $outfh, undef, @_);
 }
 
 # override as NOOPs
-sub close {}
-sub xclose {}
+sub close  { }
+sub xclose { }
 
 1
