@@ -127,7 +127,7 @@ use Scalar::Util qw(blessed);
 use FP::Carp;
 
 sub keyshow {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($str) = @_;
     (
         $str =~ /^\w+$/s
@@ -236,7 +236,7 @@ our $primitive_show = +{
 };
 
 sub show {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($v) = @_;
     if (defined blessed($v)) {
         if (my $m = $v->can("FP_Show_show")) {
